@@ -1,4 +1,14 @@
-#__init__.py
+"""
+These functions examine or manipulate Image data in the xarray Dataset (xds) format.  They
+take an xds as input and return a new xds or some other structure as
+output.  Some may operate directly on the zarr data store on
+disk.
+
+The input xarray Dataset is never modified.
+
+To access these functions, use your favorite variation of:
+``import cngi.image``
+"""
 from .contsub import contsub
 from .corr_to_stokes import corr_to_stokes
 from .cube_to_mfs import cube_to_mfs
@@ -9,7 +19,7 @@ from .gaussianbeam import gaussianbeam
 from .implot import implot
 from .mask import mask
 from .mfs_to_cube import mfs_to_cube
-from .moments import moment
+from .moments import moments
 from .posvel import posvel
 from .rebin import rebin
 from .reframe import reframe
